SDM2FF: 2-Span Slope Deflection Method(Fixed-Fixed)

Description Usage Arguments Details Value Note Author(s) References See Also Examples

Description

This function computes the moments and the rotations using slope deflection method(SDM).

Usage

1
2
SDM2FF(LengthAB, LengthBC, Typeof1, Typeof2, Magnitude1, Magnitude2, Pointof1,
  Pointof2, EAB, EBC, IAB, IBC)

Arguments

LengthAB

The length of span AB

LengthBC

The length of span BC

Typeof1

The type of load(i.e., UDL/PL/TDLS/TDLE) on span AB

Typeof2

The type of load(i.e., UDL/PL/TDLS/TDLE) on span BC

Magnitude1

The magnitude of the load on span AB

Magnitude2

The magnitude of the load on span BC

Pointof1

The point at which the load is applied on span AB

Pointof2

The point at which the load is applied on span BC

EAB

Young's Modulus(E) of span AB

EBC

Young's Modulus(E) of span BC

IAB

Inertia(second moment of area, I) of span AB

IBC

Inertia(second moment of area, I) of span BC

Details

Given the span length, magnitude of load, type of load, point of action, Young's Modulus, and interia, the function computes the moments and the rotations using SDM.

Value

Moments and Rotations

Note

The possible values for Typeof1 and Typeof2 are UDL/PL/TDLS/TDLE.
UDL:Uniformly Distributed Load
PL:Point Load
TDLS:Triangular Distributed Load(the maximum value is at the start, see http://www.abzwater.com/sdm)
TDLE:Triangular Distributed Load(the maximum value is at the end, see http://www.abzwater.com/sdm )

Author(s)

Sivarajah Mylevaganam

References

(1) Wikipedia contributors. (2018, February 19). Slope deflection method. In Wikipedia, The Free Encyclopedia. Retrieved 09:17, March 26, 2018, from https://en.wikipedia.org/w/index.php?title=Slope_deflection_method&oldid=826540985

(2) Norris, Charles Head; John Benson Wilbur; Senol Utku (1976). Elementary Structural Analysis (3rd ed.). McGraw-Hill. pp. 313–326. ISBN 0-07-047256-4.

(3) McCormac, Jack C.; Nelson, James K. Jr. (1997). Structural Analysis: A Classical and Matrix Approach (2nd ed.). Addison-Wesley. pp. 430–451. ISBN 0-673-99753-7.

See Also

SDM2FS SDM2FSC

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
Single load on a span (http://www.abzwater.com/sdm)
SDM2FF(3,2,"UDL","PL",20,40,1,1,1,1,1,1)
SDM2FF(3,2,"PL","PL",40,40,2,1,1,1,1,1)
SDM2FF(3,2,"PL","PL",40,40,2,1,2,1,3,1)

Multiple load on a span(http://www.abzwater.com/sdm)
SDM2FF(3,2,"PL","PL",40,40,1,1,1,1,1,1)+ SDM2FF(3,2,"PL","PL",40,0,2,1,1,1,1,1)
SDM2FF(3,2,"UDL","PL",20,40,1,1,1,1,1,1) + SDM2FF(3,2,"PL","PL",40,0,1,1,1,1,1,1)
SDM2FF(3,3,"UDL","UDL",20,30,1,1,1,1,1,1)

Framed  Structure(http://www.abzwater.com/sdm)
SDM2FF(5,10,"PL","UDL",0,5,1,1,1,1,1,1)

sivarajahm/CEngineering documentation built on May 17, 2019, 8:44 p.m.