Description Usage Arguments Details Value Note Author(s) References See Also Examples
This function computes the moments and the rotations using slope deflection method(SDM).
1 2 | SDM2FSC(LengthAB, LengthBC, Typeof1, Typeof2, Magnitude1, Magnitude2, Pointof1,
Pointof2, EAB, EBC, IAB, IBC, CM, CMomentDirection)
|
LengthAB |
The length of span AB |
LengthBC |
The length of span BC |
Typeof1 |
The type of load(i.e., UDL/PL/TDLS/TDLE) on span AB |
Typeof2 |
The type of load(i.e., UDL/PL/TDLS/TDLE) on span BC |
Magnitude1 |
The magnitude of the load on span AB |
Magnitude2 |
The magnitude of the load on span BC |
Pointof1 |
The point at which the load is applied on span AB |
Pointof2 |
The point at which the load is applied on span BC |
EAB |
Young's Modulus(E) of span AB |
EBC |
Young's Modulus(E) of span BC |
IAB |
Inertia(second moment of area, I) of span AB |
IBC |
Inertia(second moment of area, I) of span BC |
CM |
Moment value |
CMomentDirection |
Moment direction |
Given the span length, magnitude of load, type of load, point of action, Young's Modulus, and interia, the function computes the moments and the rotations using SDM.
Moments and Rotations
The possible values for Typeof1 and Typeof2 are UDL/PL/TDLS/TDLE.
The possible value for CMomentDirection is "C" if clock-wise.
UDL:Uniformly Distributed Load
PL:Point Load
TDLS:Triangular Distributed Load(the maximum value is at the start, see http://www.abzwater.com/sdm)
TDLE:Triangular Distributed Load(the maximum value is at the end, see http://www.abzwater.com/sdm )
Sivarajah Mylevaganam
(1) Wikipedia contributors. (2018, February 19). Slope deflection method. In Wikipedia, The Free Encyclopedia. Retrieved 09:17, March 26, 2018, from https://en.wikipedia.org/w/index.php?title=Slope_deflection_method&oldid=826540985
(2) Norris, Charles Head; John Benson Wilbur; Senol Utku (1976). Elementary Structural Analysis (3rd ed.). McGraw-Hill. pp. 313–326. ISBN 0-07-047256-4.
(3) McCormac, Jack C.; Nelson, James K. Jr. (1997). Structural Analysis: A Classical and Matrix Approach (2nd ed.). Addison-Wesley. pp. 430–451. ISBN 0-673-99753-7.
SDM2FS SDM2FF
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.