SDM2FSCSuper: 2-Span Slope Deflection Method(Fixed-Support-Cantilever) with...

Description Usage Arguments Details Value Note Author(s) References See Also Examples

Description

This function computes the moments and the rotations using slope deflection method(SDM).

Usage

1
SDM2FSCSuper(InputMatrix)

Arguments

InputMatrix

The matrix with parameter values for SDM2FSC().

Details

Given the span length, magnitude of load, type of load, point of action, Young's Modulus, and interia, the function computes the moments and the rotations using SDM.

Value

Moments and Rotations

Note

The possible values for Typeof1 and Typeof2 are UDL/PL/TDLS/TDLE.
The possible value for CMomentDirection is "C" if clock-wise.
UDL:Uniformly Distributed Load
PL:Point Load
TDLS:Triangular Distributed Load(the maximum value is at the start, see http://www.abzwater.com/sdm)
TDLE:Triangular Distributed Load(the maximum value is at the end, see http://www.abzwater.com/sdm )

Author(s)

Sivarajah Mylevaganam

References

(1) Wikipedia contributors. (2018, February 19). Slope deflection method. In Wikipedia, The Free Encyclopedia. Retrieved 09:17, March 26, 2018, from https://en.wikipedia.org/w/index.php?title=Slope_deflection_method&oldid=826540985

(2) Norris, Charles Head; John Benson Wilbur; Senol Utku (1976). Elementary Structural Analysis (3rd ed.). McGraw-Hill. pp. 313–326. ISBN 0-07-047256-4.

(3) McCormac, Jack C.; Nelson, James K. Jr. (1997). Structural Analysis: A Classical and Matrix Approach (2nd ed.). Addison-Wesley. pp. 430–451. ISBN 0-673-99753-7.

See Also

SDM2FF SDM2FS SDM2FSC

Examples

1
2
3
Multiple load on a span (http://www.abzwater.com/sdm/mload)
inputMatrix=matrix(c(3,2,"UDL","PL",20,40,1,1,1,1,1,1,10,"C",3,2,"PL","PL",40,0,1,1,1,1,1,1,0,"C"), nrow=2, byrow=TRUE)
SDM2FSCSuper(inputMatrix)

sivarajahm/CEngineering documentation built on May 17, 2019, 8:44 p.m.