Description Usage Arguments Details Value Note Author(s) References See Also Examples
This function computes the moments and the rotations using slope deflection method(SDM).
1 2 3 | SDM3FF(LengthAB, LengthBC, LengthCD, Typeof1, Typeof2, Typeof3, Magnitude1,
Magnitude2, Magnitude3, Pointof1, Pointof2, Pointof3, EAB, EBC, ECD, IAB, IBC,
ICD)
|
LengthAB |
The length of span AB |
LengthBC |
The length of span BC |
LengthCD |
The length of span CD |
Typeof1 |
The type of load(i.e., UDL/PL/TDLS/TDLE) on span AB |
Typeof2 |
The type of load(i.e., UDL/PL/TDLS/TDLE) on span BC |
Typeof3 |
The type of load(i.e., UDL/PL/TDLS/TDLE) on span CD |
Magnitude1 |
The magnitude of the load on span AB |
Magnitude2 |
The magnitude of the load on span BC |
Magnitude3 |
The magnitude of the load on span CD |
Pointof1 |
The point at which the load is applied on span AB |
Pointof2 |
The point at which the load is applied on span BC |
Pointof3 |
The point at which the load is applied on span CD |
EAB |
Young's Modulus(E) of span AB |
EBC |
Young's Modulus(E) of span BC |
ECD |
Young's Modulus(E) of span CD |
IAB |
Inertia(second moment of area, I) of span AB |
IBC |
Inertia(second moment of area, I) of span BC |
ICD |
Inertia(second moment of area, I) of span CD |
Given the span length, magnitude of load, type of load, point of action, Young's Modulus, and interia, the function computes the moments and the rotations using SDM.
Moments and Rotations
The possible values for Typeof1, Typeof2, and Typeof3 are UDL/PL/TDLS/TDLE.
UDL:Uniformly Distributed Load
PL:Point Load
TDLS:Triangular Distributed Load(the maximum value is at the start, see http://www.abzwater.com/sdm)
TDLE:Triangular Distributed Load(the maximum value is at the end, see http://www.abzwater.com/sdm )
Sivarajah Mylevaganam
(1) Wikipedia contributors. (2018, February 19). Slope deflection method. In Wikipedia, The Free Encyclopedia. Retrieved 09:17, March 26, 2018, from https://en.wikipedia.org/w/index.php?title=Slope_deflection_method&oldid=826540985
(2) Norris, Charles Head; John Benson Wilbur; Senol Utku (1976). Elementary Structural Analysis (3rd ed.). McGraw-Hill. pp. 313–326. ISBN 0-07-047256-4.
(3) McCormac, Jack C.; Nelson, James K. Jr. (1997). Structural Analysis: A Classical and Matrix Approach (2nd ed.). Addison-Wesley. pp. 430–451. ISBN 0-673-99753-7.
SDM2FS SDM2FSC SDM2FF
1 2 3 4 5 6 7 8 9 10 11 | Single load on a span (http://www.abzwater.com/sdm)
SDM3FF(8,4,8,"PL","UDL","PL",40,24,20,4,1,4,1,1,1,1,1,1)
SDM3FF(2,2,2,"UDL","UDL","UDL",40,40,40,1,1,1,1,1,1,1,1,1)
SDM3FF(2,2,2,"UDL","UDL","UDL",40,80,40,1,1,1,1,1,1,1,1,1)
Multiple load on a span(http://www.abzwater.com/sdm)
SDM3FF(5,10,5,"PL","PL","PL",0,40,0,1,3,1,1,1,1,1,1,1) + SDM3FF(5,10,5,"PL","PL","PL",0,40,0,1,7,1,1,1,1,1,1,1)
Framed Structure(http://www.abzwater.com/sdm)
SDM3FF(5,10,5,"PL","UDL","PL",0,5,0,1,1,1,1,1,1,1,1,1)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.